from holehe.core import *
from holehe.localuseragent import *


async def protonmail(email, client, out):
    #credit https://github.com/pixelbubble/ProtOSINT
    name = "protonmail"
    try:
        response = await client.get('https://api.protonmail.ch/pks/lookup?op=index&search='+email)
        if "info:1:0" in response.text :
            out.append({"name": name,
                        "rateLimit": False,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
        elif "info:1:1" in response.text:
            regexPattern1 = "2048:(.*)::"
            regexPattern2 = "4096:(.*)::"
            try:
                timestamp = int(re.search(regexPattern1, response.text).group(1))
            except:
                timestamp = int(re.search(regexPattern2, response.text).group(1))
            dtObject = datetime.fromtimestamp(timestamp)
            out.append({"name": name,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": {"Date, time of the creation":str(dtObject)} })
        else:
            out.append({"name": name,
                        "rateLimit": True,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
    except :
        out.append({"name": name,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def fetlife(email, client, out):
    name = "fetlife"
    headers = {
        'User-Agent': random.choice(ua["browsers"]["chrome"]),
        'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
        'Accept-Language': 'en,en-US;q=0.5',
        'DNT': '1',
        'Connection': 'keep-alive',
        'Upgrade-Insecure-Requests': '1',
    }
    try:
        req = await client.get("https://fetlife.com/signup_step_profile", headers=headers)
    except BaseException:
        out.append({"name": name,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None

    soup = BeautifulSoup(req.content, features="html.parser")

    inp_method = soup.find(
        "input",
        attrs={
            "type": "hidden",
            "name": "_method"})
    inp_authenticity_token = soup.find(
        "input",
        attrs={"type": "hidden", "name": "authenticity_token"}
    )

    if inp_method is None or inp_authenticity_token is None:
        raise NotImplementedError(
            "Fetlife register page changed, this module need to be updated."
        )

    data = {
        "_method": inp_method.get("value"),
        "authenticity_token": inp_authenticity_token.get("value"),
        "user[nickname]": "",
        "user[email]": email,
        "user[password]": "",
    }

    post = await client.post(
        "https://fetlife.com/signup_step_profile",
        headers=headers,
        data=data
    )
    resp_soup = BeautifulSoup(post.content, features="html.parser")

    EMAIL_MSG_ERROR = (
        "We're having problems processing the above email address. "
        "We recommend you verify the spelling or try a different one."
    )

    email_error_tag = resp_soup.findAll(text=EMAIL_MSG_ERROR)

    email_is_present = len(email_error_tag) > 0

    out.append({"name": name,
                "rateLimit": False,
                "exists": email_is_present,
                "emailrecovery": None,
                "phoneNumber": None,
                "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def mail_ru(email, client, out):
    name = "mail_ru"
    headers = {
        'authority': 'account.mail.ru',
        'accept': 'application/json, text/javascript, */*; q=0.01',
        'x-requested-with': 'XMLHttpRequest',
        'content-type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'origin': 'https://account.mail.ru',
        'sec-fetch-site': 'same-origin',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://account.mail.ru/recovery?email={email}',
        'user-agent': random.choice(ua["browsers"]["chrome"]),
        'accept-language': 'ru',
    }

    data = 'email={email}&htmlencoded=false'.replace('@', '%40')

    response = await client.post(
        'https://account.mail.ru/api/v1/user/password/restore',
        headers=headers,
        data=data)

    if response.status_code == 200:
        try:
            reqd = response.json()
            if reqd['status'] == 200:
                phones = ', '.join(reqd['body'].get('phones', [])) or None
                emails = ', '.join(reqd['body'].get('emails', [])) or None
                out.append({"name": name,
                            "rateLimit": False,
                            "exists": True,
                            "emailrecovery": emails,
                            "phoneNumber": phones,
                            "others": None})
            else:
                # email not exists or some problem
                out.append({"name": name,
                            "rateLimit": False,
                            "exists": False,
                            "emailrecovery": None,
                            "phoneNumber": None,
                            "others": None})
        except BaseException:
            out.append({"name": name,
                        "rateLimit": True,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
    else:
        out.append({"name": name,
                    "rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})



from holehe.core import *
from holehe.localuseragent import *


async def vivino(email, client, out):
    name = "vivino"
    headers = {
        'User-Agent': random.choice(ua["browsers"]["firefox"]),
        'Accept': 'application/json',
        'Referer': 'https://www.vivino.com/',
        'Accept-Language': 'en-US,en;q=0.5',
        'X-Requested-With': 'XMLHttpRequest',
        'Content-Type': 'application/json',
        'Connection': 'keep-alive',
        'TE': 'Trailers',
    }

    r = await client.get("https://www.tunefind.com/user/join", headers=headers)
    try:
        crsf_token = r.text.split('"csrf-token" content="')[1].split('"')[0]
    except BaseException:
        out.append({"rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
        return None

    headers['X-CRSF-Token'] = crsf_token
    data = '{"email":"' + str(email) + '","password":"e"}'

    response = await client.post('https://www.vivino.com/api/login', headers=headers, data=data)
    if response.status_code == 429:
        out.append({"rateLimit": True,
                    "exists": False,
                    "emailrecovery": None,
                    "phoneNumber": None,
                    "others": None})
    else:
        if response.json()['error'] == "The supplied email does not exist":
            out.append({"name": name,
                        "rateLimit": False,
                        "exists": False,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
        else:
            out.append({"name": name,
                        "rateLimit": False,
                        "exists": True,
                        "emailrecovery": None,
                        "phoneNumber": None,
                        "others": None})
